<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el_GR">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translatorcomment>Πλοηγός = browser, though many people call it just &quot;browser&quot;</translatorcomment>
        <translation>Υπάρχει ζωή έξω απο τον πλοηγό!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Έκδοση %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation type="obsolete">Αυτή είναι μια έκδοση «Επίδειξης Τεχνολογίας », μην περιμένετε να είναι τέλεια.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Αναφέρετε προβλήματα και στείλτε τις ιδέες σας στην διεύθυνση %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>Το %1 είναι Ελεύθερο Λογισμικό αλλά η ανάπτυξη του παίρνει πολύτιμο χρόνο.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="obsolete">Παρακαλούμε &lt;a href=&apos;%1&apos;&gt;δωρίστε μέσω PayPal&lt;/a&gt; για να υποστηρίξετε την συνεχόμενη ανάπτυξη του %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Σχεδιασμός εικονιδίου από %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Μετάφραση από %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Έκδοση κάτω απο τους όρους της &lt;a href=&apos;%1&apos;&gt;Γενικής Άδειας Χρήσης GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Σχετικά</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Ότι θέλατε να μάθετε σχετικά με το %1 και δεν τολμούσατε να ρωτήσετε</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Συνεισφορά της συμπαγούς εμφάνισης (Compact Mode) από %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Συνεισφορά υποστήριξης μεσολαβητή HTTP (proxy) από %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Версія для Windows %1</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Παρακαλούμε &lt;a href=&apos;%1%&apos;&gt;δωρίστε&lt;/a&gt; για να υποστηρίξετε την συνεχόμενη ανάπτυξη του %2.</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Καθαρισμός</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation></translation>
    </message>
    <message>
        <source>KB</source>
        <translation></translation>
    </message>
    <message>
        <source>MB</source>
        <translation></translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation></translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation></translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation></translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>δευτερόλεπτα</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>λεπτά</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>απομένουν %4 %5</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>%n Λήψεις</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Αυτή είναι απλά η δοκιμαστική έκδοση του %1.</translation>
    </message>
    <message>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>Μπορεί να κατεβάσει βίντεο μικρότερα από %1 λεπτά ώστε να δοκιμάσετε τη λειτουργία κατεβάσματος.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Συνέχεια</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Αποκτήστε την πλήρη έκδοση</translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Αλλάξτε τοποθεσία...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Επιλέξτε την τοποθεσία λήψης</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Η τοποθεσία λήψης άλλαξε.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Τα ήδη ληφθέντα θα παραμείνουν στην προηγούμενη τοποθεσία.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Λήψη στο: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Λήψεις</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Αναπαραγωγή</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Παύση</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Αναπαραγωγή/Παύση</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Διακοπή</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Διακοπή αναπαραγωγής μετά το τρέχον κομμάτι</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Επόμενο κομμάτι</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Προηγούμενο κομμάτι</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Αύξηση έντασης</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Μείωση έντασης</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Σίγαση</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Αναζήτηση μπροστά</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Αναζήτηση πίσω</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Αναζήτηση...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Εμφάνιση %1 ακόμα</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Κανένα βίντεο</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Δεν υπάρχουν άλλα βίντεο</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation type="obsolete">&amp;Πίσω</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation type="obsolete">Alt+Вліво</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation type="obsolete">Προς την προηγούμενη όψη (view)</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Στοπ</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Στοπ αναπαραγωγής και επιστροφή στην όψη αναζήτησης</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="obsolete">Esc</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Παράλειψη</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Παράλειψη προς το επόμενο βίντεο</translation>
    </message>
    <message>
        <source>Ctrl+Right</source>
        <translation type="obsolete">Ctrl+Вправо</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Διακοπή</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Διακοπή αναπαραγωγής</translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="obsolete">Клавіша пробілу</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Πλήρης Οθόνη</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Προβολή σε Πλήρη Οθόνη</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation type="obsolete">Alt+Enter</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation type="obsolete">&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation type="obsolete">Άνοιγμα σελίδας YouTube</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation type="obsolete">Ctrl+Y</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Αφαίρεση</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Αφαίρεση επιλεγμένων βίντεο απο την λίστα αναπαραγωγής</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Μετακίνηση προς τα &amp;πάνω</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Μετακίνηση επιλεγμένων βίντεο προς τα πάνω</translation>
    </message>
    <message>
        <source>Ctrl+Up</source>
        <translation type="obsolete">Ctrl+Вгору</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Μετακίνηση προς τα &amp;κάτω</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Μετακίνηση επιλεγμένων βίντεο προς τα κάτω</translation>
    </message>
    <message>
        <source>Ctrl+Down</source>
        <translation type="obsolete">Ctrl+Вниз</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Έ&amp;ξοδος</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Γεια</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Ιστοχώρος</translation>
    </message>
    <message>
        <source>Minitube on the Web</source>
        <translation type="obsolete">Minitube в мережі</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>Το %1 στο διαδίκτυο</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation type="obsolete">Δωρεά μέσω Pa&amp;yPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Παρακαλούμε υποστηρίξτε την συνεχόμενη ανάπτυξη του %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Σχετικά</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Πληροφορίες για %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">Пош&amp;ук</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Εφαρμογή</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Λ&amp;ίστα αναπαραγωγής</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>Βίν&amp;τεο</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Άνοιγμα %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Α&amp;ναπαραγωγή</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Συνέχεια αναπαραγωγής</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Έξο&amp;δος απο Πλήρη Οθόνη</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>&amp;Συμπαγής εμφάνιση</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Απόκρυψη λίστας αναπαραγωγής και εργαλειοθήκης</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Θανάσιμο σφάλμα : %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Σφάλμα: %1</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Ένταση στο %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Σίγαση</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Η ένταση αποκαταστάθηκε</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Αναζήτηση</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Σίγαση</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Πατήστε %1 για να αυξήσετε την ένταση, %2 για να την χαμηλώσετε</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Υπολειπόμενος χρόνος: %1</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation type="obsolete">Βίντεο Υψηλής Ανάλυσης ενεργό</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation type="obsolete">Βίντεο Υψηλής Ανάλυσης ανενεργό</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation type="obsolete">Το τρέχων βίντεο είναι σε Υψηλή Ανάλυση</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation type="obsolete">Το τρέχων βίντεο δεν είναι σε Υψηλή Ανάλυση</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>&amp;Καθαρισμός πρόσφατων αναζητήσεων</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Καθαρισμός του ιστορικού αναζήτησης. Δεν μπορεί να γίνει επαναφορά.</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Η ιδιωτικότητα σας είναι τώρα ασφαλής</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>Ανοίξτε την ιστοσελίδα του &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Πλοήγηση στην σελίδα βίντεο του YouTube και παύση αναπαραγωγής</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translatorcomment>link=σύνδεσμος, however link is more commonly used</translatorcomment>
        <translation>Αντιγραφή του YouTube &amp;link</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Αντιγραφή του link του τρέχοντος YouTube βίντεο στην μνήμη</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>Αντιγραφή του &amp;URL της ροής βίντεο</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Αντιγραφή του URL της τρέχουσας ροής βίντεο στην μνήμη</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Κάντε μια &amp;δωρεά</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>H μέγιστη ανάλυση βίντεο τέθηκε σε %1</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Λήψεις</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Εμφάνιση λεπτομερειών για τις λήψεις βίντεο</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Λήψη</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Λήψη του τρέχοντος βίντεο</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Θέλετε να κλείσετε το %1 ενώ βρίσκεται μια λήψη σε εξέλιξη;</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Αν κλείσετε το %1 τώρα, η λήψη θα ακυρωθεί.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Κλείσιμο και ακύρωση λήψης</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Αναμονή ολοκλήρωσης λήψης</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Οι λήψεις ολοκληρώθηκαν</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Πιο σχετικά</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Πιο πρόσφατα</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Πιο προβεβλημένα</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Βλέπετε «%1»</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Τώρα μπορείτε να επικολλήσετε το YouTube link σε κάποια άλλη εφαρμογή</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Τώρα μπορείτε να επικολλήσετε το URL της ροής βίντεο σε κάποια άλλη εφαρμογή</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Ο σύνδεμος θα είναι έγκυρος μόνο για περιορισμένο χρονικό διάστημα.</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Αυτή είναι απλά μια δοκιμαστική έκδοση του %1.</translation>
    </message>
    <message>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>Σαε επιτρέπει να δοκιμάσετε την εφαρμογή και να δείτε αν σας κάνει.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Συνέχεια</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Αποκτήστε την πλήρη έκδοση</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Λήψη %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Σφάλμα δικτύου: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>Προβολές %1</translation>
    </message>
    <message>
        <source>%1 of %2 (%3) ? %4</source>
        <translatorcomment>needed description of what this variables represent so it can be translated..</translatorcomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Προετοιμάζεται</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Απέτυχε</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Ολοκληρώθηκε</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Διακόπηκε</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Διακοπή λήψης</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Εμφάνιση σε %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Άνοιγμα γονικού φακέλου</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Επανεκκίνηση λήψης</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Αναζήτηση</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Καλωσορίσατε στο &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Εισάγετε μια λέξη-κλειδί για να αρχίσετε να βλέπετε βίντεο.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Δείτε</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Πρόσφατες λέξεις-κλειδιά</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Μια νέα έκδοση του %1 είναι διαθέσιμη. Παρακαλούμε&lt;a href=&apos;%2&apos;&gt; αναβαθμίστε στην έκδοση %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Βολευτείτε</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Επιλογές</translation>
    </message>
    <message>
        <source>&amp;Video options</source>
        <translation type="obsolete">Відео &amp;можливості</translation>
    </message>
    <message>
        <source>Use high quality video when available</source>
        <translation type="obsolete">Відтворювати відео високої якості при наявності</translation>
    </message>
    <message>
        <source>&amp;Saved recent keywords</source>
        <translation type="obsolete">&amp;Збережені недавні терміни пошуку</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="obsolete">Очистити недавн&amp;і терміни пошуку</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">За&amp;крити</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Σφάλμα δικτύου: %1 για %2</translation>
    </message>
</context>
</TS>
